# LLamp - Large Languge Models for Planning

This is a package that uses LLMs (closed and open-source) for planning and reasoning.

This package is under development. 

## Purpose of this package:
1. To help with running different LLMs (both local and API-based) in a unified manner.
2. To provide useful utility functions (such as counting tokens)
3. Automatic Tracking of the entire conversation with the agent


## Reference:
Please cite the paper StateAct: [https://arxiv.org/abs/2410.02810]
```bibtex
@article{rozanov2024stateactstatetrackingreasoning,
      title={StateAct: State Tracking and Reasoning for Acting and Planning with Large Language Models}, 
      author={Nikolai Rozanov and Marek Rei},
      year={2024},
      eprint={2410.02810},
      archivePrefix={arXiv},
      primaryClass={cs.AI},
      url={https://arxiv.org/abs/2410.02810}, 
}
```
